unit euroform;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons, ExtCtrls;

type
  TForm1 = class(TForm)
    InputEdit: TEdit;
    ConvertButton: TButton;
    ValutaRadioG: TRadioGroup;
    EuroLabel: TLabel;
    BEFLabel: TLabel;
    NLGLabel: TLabel;
    FRFLabel: TLabel;
    Bevel1: TBevel;
    DecimRadioG: TRadioGroup;
    procedure ConvertButtonClick(Sender: TObject);
    procedure ValutaRadioGClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure InputEditKeyPress(Sender: TObject; var Key: Char);
    procedure DecimRadioGClick(Sender: TObject);
  private
    { Private declarations }
    procedure ConvertShow;
    procedure SetLabelInvisible;
    procedure ValutaConvert;
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}

const
  // Conversie-factoren voor de valuta
  // 1 EURO = X munteenheden
  cfBEF  = 40.3399;
  cfFRF  = 6.55957;
  cfNLG  = 2.20371;

var
  Euro: Real;

procedure TForm1.ConvertButtonClick(Sender: TObject);
begin
  ValutaConvert;
end;

procedure TForm1.ValutaRadioGClick(Sender: TObject);
begin
  ValutaConvert;
end;

{ Converteer de inhoud van de EDIT naar Euro,
  converteer naar de andere valuta,
  toon de resultaten in LABELs.               }
procedure TForm1.ValutaConvert;
var
  StartBedrag: real;
begin
  // Converteer tekst van de EDIT naar een numerieke waarde
  StartBedrag := StrToFloat(InputEdit.Text);

  // Bereken bedrag in Euro
  if ValutaRadioG.ItemIndex = 1 then // tweede button: BEF
    Euro := StartBedrag / cfBEF
  else
    if ValutaRadioG.ItemIndex = 2 then // derde button: FRF
      Euro := StartBedrag / cfFRF
    else
      if ValutaRadioG.ItemIndex = 3 then // vierde button: NLG
        Euro := StartBedrag / cfNLG
      else                                // eerste button: Euro
        Euro := StartBedrag;

  // Converteer naar andere valuta en toon resultaten
  ConvertShow;

  // Verberg LABEL naast de geselecteerde RADIOBUTTON
  SetLabelInvisible;
end;

{ Converteer van Euro naar de andere valuta
  en toon de resultaten                     }
procedure TForm1.ConvertShow;
var
  FStr: string; // formaat-string
begin
  { Het aantal decimalen hangt af van welke Radiobutton
    geselecteed is in DecimRadioG                      }
  if DecimRadioG.ItemIndex = 0 then
    FStr := '0.00'
  else
    FStr := '0.0000';

  { Converteer van Euro naar de andere valuta,
    formatteer, laat volgen door de munteenheid,
    vul aan met spaties zodat alles even lang wordt,
    plaats de strings in de CAPTION van de LABELs   }
  EuroLabel.Caption := FormatFloat(FStr, Euro)         + ' EURO   ';
  BEFLabel.Caption  := FormatFloat(FStr, Euro * cfBEF) + ' BEF/LUF';
  FRFLabel.Caption  := FormatFloat(FStr, Euro * cfFRF) + ' FRF    ';
  NLGLabel.Caption  := FormatFloat(FStr, Euro * cfNLG) + ' NLG    ';
end;

{ Verberg het LABEL dat naast de geselecteerde RADIOBUTTON
  staat, maak de andere LABELs zichtbaar                  }
procedure TForm1.SetLabelInvisible;
begin
  EuroLabel.Visible := (ValutaRadioG.ItemIndex <> 0);
  BEFLabel.Visible  := (ValutaRadioG.ItemIndex <> 1);
  FRFLabel.Visible  := (ValutaRadioG.ItemIndex <> 2);
  NLGLabel.Visible  := (ValutaRadioG.ItemIndex <> 3);
end;

{ Deze event handler wordt slechts eenmaal uitgevoerd,
  namelijk bij de start van het programma.
  Hier regelen we de eerste "automatische" conversie  }
procedure TForm1.FormCreate(Sender: TObject);
begin
  ValutaConvert;
end;

{ Wanneer InputEdit de focus heeft en wanneer op ENTER gedrukt
  wordt, doen we ook een conversie                             }
procedure TForm1.InputEditKeyPress(Sender: TObject; var Key: Char);
begin
  // 13 is de code voor de ENTER toets
  if Key = #13 then ValutaConvert;
end;

procedure TForm1.DecimRadioGClick(Sender: TObject);
begin
  ValutaConvert;
end;

end.
